| Title: | Extraction of regression information from Stata reproduction run (before metareg) |
|---|---|
| Description: | Core part of previous huge repboxReg package. Only the functionality related to the original reproduction run, no metareg stuff. |
| Authors: | Sebastian Kranz [aut, cre] |
| Maintainer: | Sebastian Kranz <[email protected]> |
| License: | GPL >= 2.0 |
| Version: | 0.1.0 |
| Built: | 2026-06-03 08:32:38 UTC |
| Source: | https://github.com/repboxr/repboxStataReg |